# Lefaire

## Application de gestion de tâches

### Installation

Pour installer Lefaire : `pip install lefaire`

### Configuration

Afin de pouvoir fonctionner Lefaire doit se connecter à une base de données MariaDB.

Pour effectuer la configuration `lefaire info`, puis renseigner le mot de passe root de MariaDB.
Le mot de passe ne sera utiliser uniquement pour créer une base de données et un utilisateur "lefaire"@"localhost" ayant accès à cette base de données

### Commandes

`lefaire --help` vous renseignera toutes les commandes
